PyXMake Developer Guide: PyXMake.VTL.stm_make.f2py_boxbeam Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Protected Member Functions | Static Protected Attributes | List of all members
PyXMake.VTL.stm_make.f2py_boxbeam Class Reference
Inheritance diagram for PyXMake.VTL.stm_make.f2py_boxbeam:

## Protected Member Functions
| _create_command (self)
Protected Member Functions inherited from PyXMake.VTL.stm_make.pyx_f2py
| _run_command (self, command)
Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _perform_post_actions (self)

## Static Protected Attributes
int | _KEY_OPT = 1
str | _PACKAGE_NAME = 'bbeam'
| _INPUT_FILES = GetSourceCode(_KEY_OPT)
Static Protected Attributes inherited from PyXMake.VTL.stm_make.pyx_f2py
str | _PACKAGE_NAME = ''
list | _INPUT_FILES = []

## Additional Inherited Members
Public Member Functions inherited from PyXMake.VTL.stm_make.pyx_f2py
| initialize_options (self)
| finalize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| run (self)
Public Attributes inherited from PyXMake.VTL.stm_make.pyx_f2py
int | verbose = 2
str | source_path = ''
str | output_file_path = ''
str | base_path = ''
| scratch_path = os.getcwd()
| libs = None
| includes = None
| libpaths = None
bool | incremental = False
str | msvsc = "vs2015"
Public Attributes inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| verbose
Static Public Attributes inherited from PyXMake.VTL.stm_make.pyx_f2py
str | description = "Runs the build process of Fortran source code for Python using f2py."
list | user_options
Static Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _create_build_dir ()
Protected Attributes inherited from PyXMake.VTL.stm_make.pyx_f2py
dict | _MAKE_OPT = {"Python":0, "Java":1, "Fortran":2}

## Detailed Description

    Runs the build process for BoxBeam.

Definition at line 633 of file stm_make.py.

## Member Function Documentation

## ◆ _create_command()

PyXMake.VTL.stm_make.f2py_boxbeam._create_command | ( |  | self | ) |
| protected

Reimplemented from PyXMake.VTL.stm_make._BaseCommandRunner.

Definition at line 644 of file stm_make.py.

## Member Data Documentation

## ◆ _INPUT_FILES

PyXMake.VTL.stm_make.f2py_boxbeam._INPUT_FILES = GetSourceCode(_KEY_OPT)
| staticprotected

Definition at line 642 of file stm_make.py.

## ◆ _KEY_OPT

int PyXMake.VTL.stm_make.f2py_boxbeam._KEY_OPT = 1
| staticprotected

Definition at line 639 of file stm_make.py.

## ◆ _PACKAGE_NAME

str PyXMake.VTL.stm_make.f2py_boxbeam._PACKAGE_NAME = 'bbeam'
| staticprotected

Definition at line 640 of file stm_make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/VTL/stm_make.py